@@ -1,5 +1,5 @@
-import keras
-import keras.backend as K
+from keras_bert.backend import keras
+from keras_bert.backend import backend as K
 from keras_pos_embd import PositionEmbedding
 from keras_layer_normalization import LayerNormalization
 
@@ -14,10 +14,10 @@ class TokenEmbedding(keras.layers.Embedding):
         return [super(TokenEmbedding, self).compute_mask(inputs, mask), None]
 
     def call(self, inputs):
-        return [super(TokenEmbedding, self).call(inputs), self.embeddings]
+        return [super(TokenEmbedding, self).call(inputs), self.embeddings + 0]
 
 
-def get_embedding(inputs, token_num, pos_num, embed_dim, dropout_rate=0.1):
+def get_embedding(inputs, token_num, pos_num, embed_dim, dropout_rate=0.1, trainable=True):
     """Get embedding layer.
 
     See: https://arxiv.org/pdf/1810.04805.pdf
@@ -27,6 +27,7 @@ def get_embedding(inputs, token_num, pos_num, embed_dim, dropout_rate=0.1):
     :param pos_num: Maximum position.
     :param embed_dim: The dimension of all embedding layers.
     :param dropout_rate: Dropout rate.
+    :param trainable: Whether the layers are trainable.
     :return: The merged embedding layer and weights of token embedding.
     """
     embeddings = [
@@ -34,11 +35,13 @@ def get_embedding(inputs, token_num, pos_num, embed_dim, dropout_rate=0.1):
             input_dim=token_num,
             output_dim=embed_dim,
             mask_zero=True,
+            trainable=trainable,
             name='Embedding-Token',
         )(inputs[0]),
         keras.layers.Embedding(
             input_dim=2,
             output_dim=embed_dim,
+            trainable=trainable,
             name='Embedding-Segment',
         )(inputs[1]),
     ]
@@ -48,17 +51,10 @@ def get_embedding(inputs, token_num, pos_num, embed_dim, dropout_rate=0.1):
         input_dim=pos_num,
         output_dim=embed_dim,
         mode=PositionEmbedding.MODE_ADD,
+        trainable=trainable,
         name='Embedding-Position',
     )(embed_layer)
-    if dropout_rate > 0.0:
-        dropout_layer = keras.layers.Dropout(
-            rate=dropout_rate,
-            name='Embedding-Dropout',
-        )(embed_layer)
-    else:
-        dropout_layer = embed_layer
-    norm_layer = LayerNormalization(name='Embedding-Norm')(dropout_layer)
-    return norm_layer, embed_weights
+    return embed_layer, embed_weights
 
 
 class EmbeddingSimilarity(keras.layers.Layer):
@@ -77,25 +73,25 @@ class EmbeddingSimilarity(keras.layers.Layer):
         :param constraint: Constraint for bias.
         :param kwargs: Arguments for parent class.
         """
+        super(EmbeddingSimilarity, self).__init__(**kwargs)
         self.supports_masking = True
         self.initializer = keras.initializers.get(initializer)
         self.regularizer = keras.regularizers.get(regularizer)
         self.constraint = keras.constraints.get(constraint)
         self.bias = None
-        super(EmbeddingSimilarity, self).__init__(**kwargs)
 
     def get_config(self):
         config = {
-            'initializer': self.initializer,
-            'regularizer': self.regularizer,
-            'constraint': self.constraint,
+            'initializer': keras.initializers.serialize(self.initializer),
+            'regularizer': keras.regularizers.serialize(self.regularizer),
+            'constraint': keras.constraints.serialize(self.constraint),
         }
         base_config = super(EmbeddingSimilarity, self).get_config()
         return dict(list(base_config.items()) + list(config.items()))
 
     def build(self, input_shape):
         self.bias = self.add_weight(
-            shape=(input_shape[1][0],),
+            shape=(int(input_shape[1][0]),),
             initializer=self.initializer,
             regularizer=self.regularizer,
             constraint=self.constraint,
