@@ -1,10 +1,11 @@
 import unittest
 import os
 import tempfile
-import random
-import keras
 import numpy as np
-from keras_bert import gelu, get_model, get_custom_objects, get_base_dict, gen_batch_inputs
+from keras_bert.backend import keras
+from keras_bert.backend import backend as K
+from keras_bert import (get_model, compile_model, get_base_dict, gen_batch_inputs, get_token_embedding,
+                        get_custom_objects, set_custom_objects)
 
 
 class TestBERT(unittest.TestCase):
@@ -15,7 +16,7 @@ class TestBERT(unittest.TestCase):
             head_num=3,
             transformer_num=2,
         )
-        model_path = os.path.join(tempfile.gettempdir(), 'keras_bert_%f.h5' % random.random())
+        model_path = os.path.join(tempfile.gettempdir(), 'keras_bert_%f.h5' % np.random.random())
         model.save(model_path)
         model = keras.models.load_model(
             model_path,
@@ -23,6 +24,49 @@ class TestBERT(unittest.TestCase):
         )
         model.summary(line_length=200)
 
+    def test_task_embed(self):
+        inputs, outputs = get_model(
+            token_num=20,
+            embed_dim=12,
+            head_num=3,
+            transformer_num=2,
+            use_task_embed=True,
+            task_num=10,
+            training=False,
+            dropout_rate=0.0,
+        )
+        model = keras.models.Model(inputs, outputs)
+        model_path = os.path.join(tempfile.gettempdir(), 'keras_bert_%f.h5' % np.random.random())
+        model.save(model_path)
+        model = keras.models.load_model(
+            model_path,
+            custom_objects=get_custom_objects(),
+        )
+        model.summary(line_length=200)
+
+    def test_save_load_json(self):
+        model = get_model(
+            token_num=200,
+            head_num=3,
+            transformer_num=2,
+            attention_activation='gelu',
+        )
+        compile_model(model)
+        data = model.to_json()
+        set_custom_objects()
+        model = keras.models.model_from_json(data)
+        model.summary()
+
+    def test_get_token_embedding(self):
+        model = get_model(
+            token_num=200,
+            head_num=3,
+            transformer_num=2,
+            attention_activation='gelu',
+        )
+        embed = get_token_embedding(model)
+        self.assertEqual((200, 768), K.int_shape(embed))
+
     def test_fit(self):
         current_path = os.path.dirname(os.path.abspath(__file__))
         model_path = os.path.join(current_path, 'test_bert_fit.h5')
@@ -38,11 +82,13 @@ class TestBERT(unittest.TestCase):
                     token_dict[token] = len(token_dict)
         token_list = list(token_dict.keys())
         if os.path.exists(model_path):
+            steps_per_epoch = 10
             model = keras.models.load_model(
                 model_path,
                 custom_objects=get_custom_objects(),
             )
         else:
+            steps_per_epoch = 1000
             model = get_model(
                 token_num=len(token_dict),
                 head_num=5,
@@ -52,8 +98,14 @@ class TestBERT(unittest.TestCase):
                 seq_len=20,
                 pos_num=20,
                 dropout_rate=0.05,
-                attention_activation=gelu,
-                lr=1e-3,
+                attention_activation='gelu',
+            )
+            compile_model(
+                model,
+                learning_rate=1e-3,
+                decay_steps=30000,
+                warmup_steps=10000,
+                weight_decay=1e-3,
             )
         model.summary()
 
@@ -70,14 +122,10 @@ class TestBERT(unittest.TestCase):
 
         model.fit_generator(
             generator=_generator(),
-            steps_per_epoch=1000,
+            steps_per_epoch=steps_per_epoch,
             epochs=1,
             validation_data=_generator(),
-            validation_steps=100,
-            callbacks=[
-                keras.callbacks.ReduceLROnPlateau(monitor='val_MLM_loss', factor=0.5, patience=3),
-                keras.callbacks.EarlyStopping(monitor='val_MLM_loss', patience=5)
-            ],
+            validation_steps=steps_per_epoch // 10,
         )
         # model.save(model_path)
         for inputs, outputs in _generator():
@@ -86,32 +134,12 @@ class TestBERT(unittest.TestCase):
             predicts = list(map(lambda x: np.argmax(x, axis=-1), predicts))
             batch_size, seq_len = inputs[-1].shape
             for i in range(batch_size):
+                match, total = 0, 0
                 for j in range(seq_len):
                     if inputs[-1][i][j]:
-                        self.assertEqual(outputs[0][i][j], predicts[0][i][j])
+                        total += 1
+                        if outputs[0][i][j] == predicts[0][i][j]:
+                            match += 1
+                self.assertGreater(match, total * 0.9)
             self.assertTrue(np.allclose(outputs[1], predicts[1]))
             break
-
-    def test_get_layers(self):
-
-        def _custom_layers(x, trainable=True):
-            return keras.layers.LSTM(
-                units=768,
-                trainable=trainable,
-                name='LSTM',
-            )(x)
-
-        inputs, output_layer = get_model(
-            token_num=200,
-            embed_dim=768,
-            custom_layers=_custom_layers,
-            training=False,
-        )
-        model = keras.models.Model(inputs=inputs, outputs=output_layer)
-        model.compile(
-            optimizer='adam',
-            loss='mse',
-            metrics={},
-        )
-        model.summary()
-        self.assertTrue(model is not None)
